#ifndef list_h_
#define list_h_

#include "liste_type.h"


/*!
************************************************
* \brief Initialise une liste d'entiers vide, 
*  en retournant un pointeur sur un element de 
* liste egal a NULL. 
* \return une liste vide, ie. un pointeur sur un 
* element de liste egal a NULL
**************************************************/    
LISTE initListe();

/*!
************************************************
* \brief Renvoie le nombre d'entiers contenus
* dans une liste d'entiers
* \param liste une liste d'entiers
* \return le nombre d'elements de la liste
**************************************************/    
int tailleListe(LISTE);	

/*!
************************************************
* \brief Affiche iterativement une liste d'entiers. 
* NB: le premier element affiche est situe en 
* tete de liste. 
* \param liste une liste d'entiers
**************************************************/    
void afficherListe(LISTE liste);	

/*!
************************************************
* \brief Ajoute un element au debut d'une liste d'entiers 
* \param pliste pointeur sur la liste 
* \param elem un entier a ajouter à la liste 
* \warning On passe un pointeur sur une liste (donc un pointeur
*   sur un pointeur sur un element)
* \return retourne 0 si il n'y a pas d'erreur, 1 sinon
* \post s'il n'y a pas d'erreur, la liste est modifiee: 
* un element est insere en tete de liste
**************************************************/    
int ajouterListe (LISTE* pliste, int elem);

/*!
************************************************
* \brief Retire un element en tete de liste
* \param pliste pointeur sur la liste
* \warning On passe un pointeur sur une liste (donc un pointeur
*   sur un pointeur sur un element)
* \return La valeur de l'element retire (0 en cas de liste nulle)
* \post l'espace memoire de l'element est libere
* et la taille de la liste est diminuee d'un element
**************************************************/
int retirerListe(LISTE* pliste);	

/*!
************************************************
* \brief vide une liste et libere l'espace memoire
* de tout ses elements
* \param pliste pointeur sur une liste
* \see retirerListe
**************************************************/
void viderListe(LISTE*);	


#endif
